require 'compass/import-once/activate'
# Require any additional compass plugins here.
require 'compass-h5bp'

css_dir = 'test/project/css'
sass_dir = 'test/project/sass'

# You can select your preferred output style here
# (can be overridden via the command line):
# output_style = :expanded or :nested or :compact or :compressed

# To enable relative paths to assets via compass helper functions. Uncomment:
# relative_assets = true

# To disable debugging comments that display the
# original location of your selectors. Uncomment:
line_comments = false
